# Generated by Django 4.0.3 on 2022-04-08 06:14

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notice', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='noticestore',
            name='receiver_type',
        ),
        migrations.AddField(
            model_name='noticestore',
            name='receiver_type_ids',
            field=django.contrib.postgres.fields.ArrayField(base_field=models.IntegerField(), null=True, size=None, verbose_name='receiver type'),
        ),
    ]
